package app.navigation.regular.components.button;

import app.data.entity.Matchday;
import app.navigation.regular.RegularNavigation;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.icon.VaadinIcon;

import java.util.Optional;

public class NextMatchdayButton extends Button {

    private final RegularNavigation regularNavigation;

    public NextMatchdayButton(RegularNavigation regularNavigation) {
        this.regularNavigation = regularNavigation;

        if (!regularNavigation.matchdayEnabled())
            throw new IllegalStateException("Cannot instantiate NextMatchdayButton when Matchdays are not enabled!");

        setIcon(VaadinIcon.ARROW_RIGHT.create());

        regularNavigation.addRunnableToBeRunAfterSelection(this::configure);
    }

    private void configure() {
        Optional<Matchday> nextMatchday = getNextMatchday();
        setEnabled(nextMatchday.isPresent());
        addClickListener(event -> nextMatchday.ifPresent(matchday -> regularNavigation.getMatchdaySelect().setValue(matchday)));
    }

    private Optional<Matchday> getNextMatchday() {
        int index = MatchdayButtonUtils.getMatchdayIndex(regularNavigation);
        if (index >= 0 && index < regularNavigation.getMatchdayList().size() - 1)
            return Optional.ofNullable(regularNavigation.getMatchdayList().get(index + 1));
        return Optional.empty();
    }
}
