package app.views.match;

import app.data.service.ChessComService;
import app.data.service.GameInfoService;
import app.data.service.GameService;
import app.gameimage.GameImageService;
import app.navigation.regular.RegularNavigationLevel;
import app.navigation.regular.RegularNavigationService;
import app.views.main.MainView;
import app.views.match.components.MatchComponent;
import app.views.navigation.NavigationViewBase;
import com.vaadin.flow.component.dependency.CssImport;
import com.vaadin.flow.router.PageTitle;
import com.vaadin.flow.router.Route;
import org.springframework.beans.factory.annotation.Autowired;

@CssImport("app/views/match/match-view.css")
@Route(value = "match", layout = MainView.class)
@PageTitle("Schachliga DACH - Results - Matches")
public class MatchView extends NavigationViewBase {

    private final ChessComService chessComService;
    private final GameService gameService;
    private final GameInfoService gameInfoService;
    private final GameImageService gameImageService;
    private MatchComponent matchComponent;

    public MatchView(@Autowired RegularNavigationService regularNavigationService,
                     @Autowired ChessComService chessComService, @Autowired GameService gameService, GameInfoService gameInfoService, GameImageService gameImageService) {
        super(regularNavigationService, "match", RegularNavigationLevel.MATCH);
        this.chessComService = chessComService;
        this.gameService = gameService;
        this.gameInfoService = gameInfoService;
        this.gameImageService = gameImageService;

        addClassName("match-view");

        configureLayout();
    }

    ////////////
    // LAYOUT //
    ////////////

    private void configureLayout() {
        matchComponent = new MatchComponent(navigation, chessComService, gameImageService);
        add(matchComponent);
    }

    /////////////
    // CONTENT //
    /////////////

    @Override
    protected void configureContent() {
        matchComponent.configureContent();
    }
}
