package app.views.navigation;

import app.navigation.AbstractNavigationHeader;
import app.navigation.Navigation;
import app.navigation.NavigationService;
import app.navigation.regular.RegularNavigation;
import app.navigation.regular.RegularNavigationLevel;
import app.navigation.regular.RegularNavigationService;
import app.navigation.regular.components.RegularNavigationHeader;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.router.BeforeEvent;
import com.vaadin.flow.router.HasUrlParameter;
import com.vaadin.flow.router.WildcardParameter;
import org.springframework.beans.factory.annotation.Autowired;

public abstract class NavigationViewBase<T extends Navigation> extends VerticalLayout implements HasUrlParameter<String> {

    protected final Navigation navigation;
    protected final AbstractNavigationHeader<T> navigationHeader;

    protected NavigationViewBase(@Autowired NavigationService<T> navigationService,
                                 String route,
                                 RegularNavigationLevel regularNavigationLevel) {
        this.navigation = navigationService.getNewNavigation();
        navigation.setRoute(route);
        if (navigation instanceof RegularNavigation) {
            ((RegularNavigation) navigation).setNavigationLevel(regularNavigationLevel);
        }

        this.navigationHeader = new RegularNavigationHeader(navigation);

        define();
    }

    protected NavigationViewBase(@Autowired RegularNavigationService regularNavigationService,
                                 String route) {
        this(regularNavigationService, route, null);
    }

    private void define() {
        add(navigationHeader);
        addClassName("content");
        setAlignItems(FlexComponent.Alignment.CENTER);

        navigation.addRunnableToBeRunAfterSelection(this::configureContent);
    }

    /////////////
    // CONTENT //
    /////////////

    protected abstract void configureContent();

    //////////////
    // OVERRIDE //
    //////////////

    @Override
    public void removeAll() {
        super.removeAll();
        add(navigationHeader);
    }

    @Override
    public void setParameter(BeforeEvent event, @WildcardParameter String param) {
        navigation.setParameter(event, param);
    }
}
